@@ -1,7 +1,8 @@
 import six
 
 from sevenbridges.meta.resource import Resource
-from sevenbridges.meta.fields import StringField, FloatField
+from sevenbridges.meta.fields import StringField, FloatField, CompoundField
+from sevenbridges.models.compound.price_breakdown import Breakdown
 
 
 class Price(Resource):
@@ -11,6 +12,7 @@ class Price(Resource):
     """
     currency = StringField(read_only=True)
     amount = FloatField(read_only=True)
+    breakdown = CompoundField(Breakdown, read_only=True)
 
     def __str__(self):
         return six.text_type(
